c ######################################################################
c #
c #                    Cu04Mn PROPERTIES PACKAGE
c #                  ------------------------------
c # Contains functions for the calculation of the thermo-physical
c # properties of Cu-0.4Mn
c #
c ######################################################################

c ######################################################################
      real function dCu04Mn(T)
c ######################################################################
c #
c # Density of Cu-0.4Mn
c #
c # Range: Tmin <= T <= Tmax K
c #
c #                        References
c #                        ----------
c # Reference
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   dCu04Mn           x    density                           kg/m**3
c #
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      dCu04Mn = 0.0
c *

      return
      end
c ######################################################################
      real function cCu04Mn(T)
c ######################################################################
c #
c # Specific heat of Cu-0.4Mn
c #
c # Range: Tmin <= T <= Tmax
c #
c #                        References
c #                        ----------
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   cCu04Mn           x    specific heat                     J/Kg K
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables

c * local variables

c *
      cCu04Mn = 0.0
c *
      return
      end
c ######################################################################
      real function kCu04Mn(T)
c ######################################################################
c #
c # Thermal conductivity of Cu-0.4Mn
c #
c # Range: Tmin <= T <= Tmax K
c #
c #                        References
c #                        ----------
c # Reference
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   kCu04Mn           x    thermal conductivity              W/m K
c #
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      kCu04Mn = 0.0
c *

      return
      end
c ######################################################################
      real function rCu04Mn(T)
c ######################################################################
c #
c # Electrical resistivity of Cu-0.4Mn
c #
c # Range: Tmin <= T <= Tmax K
c #
c #                        References
c #                        ----------
c # Reference
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   rCu04Mn           x    resistivity                       Ohm m
c #
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      rCu04Mn = 0.0
c *

      return
      end
