c ######################################################################
c #
c #                      Nb3Al PROPERTIES PACKAGE
c #                  ------------------------------
c # Contains functions for the calculation of the thermo-physical
c # properties of Nb3Al
c #
c ######################################################################

c ######################################################################
      real function dNb3Al(T)
c ######################################################################
c #
c # Density of Nb3Al
c #
c # Range: Tmin <= T <= Tmax K
c #
c #                        References
c #                        ----------
c # Reference
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   dNb3Al            x    density                           kg/m**3
c #
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      dNb3Al = 0.0
c *

      return
      end
c ######################################################################
      real function cNb3Al(T,B,Epslon)
c ######################################################################
c #
c # Specific heat of Nb3Al
c #
c # Range: Tmin <= T <= Tmax
c #
c #                        References
c #                        ----------
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   B               x      magnetic field                    T
c #   Epslon          x      strain                            -
c #   cNb3Al            x    specific heat                     J/Kg K
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c * external variables
      real     T,B,Epslon
c * fit variables

c * local variables

c *
      cNb3Al = 0.0
c *
      return
      end
c ######################################################################
      real function kNb3Al(T)
c ######################################################################
c #
c # Thermal conductivity of Nb3Al
c #
c # Range: Tmin <= T <= Tmax K
c #
c #                        References
c #                        ----------
c # Reference
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   kNb3Al            x    thermal conductivity              W/m K
c #
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      kNb3Al = 0.0
c *

      return
      end
c ######################################################################
      real function rNb3Al(T)
c ######################################################################
c #
c # Electrical resistivity of Nb3Al
c #
c # Range: Tmin <= T <= Tmax K
c #
c #                        References
c #                        ----------
c # Reference
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   rNb3Al            x    resistivity                       Ohm m
c #
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      rNb3Al = 0.0
c *

      return
      end
c ######################################################################
      real function TcNb3Al(B,Epslon)
c ######################################################################
c #
c # Critical temperature, in K, for Nb3Al as a function of applied field
c #
c #                        References
c #                        ----------
c #
c # variable    I/O               meaning                        units
c # --------------------------------------------------------------------
c #   B         x            magnetic field                        T
c #   Epslon    x            strain                                -
c #   TcNb3Al     x          critical temperature                  K
c #
c # Other functions called: NONE
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c *
      real     B,Epslon
c * fit variables      

c * local variables

c *      
      TcNb3Al = 0.0

c *
      return
      end
c ######################################################################
      real function BcNb3Al(T,Epslon)
c ######################################################################
c #
c # Upper critical field, in T, for Nb3Al as a function of field
c #
c #                        References
c #                        ----------
c #
c # variable    I/O               meaning                        units
c # --------------------------------------------------------------------
c #   T         x            magnetic field                        K
c #   Epslon    x            strain                                -
c #   BcNb3Al     x          critical field                        T
c #
c # Other functions called: NONE
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c *
      real     T,Epslon
c * fit variables      

c * local variables

c *      
      BcNb3Al = 0.0

c *
      return
      end
c ######################################################################
      real function JcNb3Al(T,B,Epslon)
c ######################################################################
c #
c # Critical (non-copper) current density, in A/m**2, for Nb3Al as a
c # function of temperature and field. 
c #
c #                        References
c #                        ----------
c #
c #
c # variable    I/O               meaning                        units
c # --------------------------------------------------------------------
c #   T         x            absolute temperature                  K
c #   B         x            magnetic field                        T
c #   Epslon    x            strain                                -
c #   JcNb3Al     x          critical current density            A/m**2
c #
c # Other functions called: NONE
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c *
      real     T,B,Epslon
c * fit variables      

c * local variables

c *      
      JcNb3Al = 0.0

c *
      return
      end
c ######################################################################
      real function TcsNb3Al(B,Epslon,Jop)
c ######################################################################
C #
C # Current sharing temperature, in K, for Nb3Al as a function of field
C # and operating current density.
C #
C # variable    I/O               meaning                        units
C # --------------------------------------------------------------------
C #   B         x            magnetic field                        T
c #   Epslon    x            strain                                -
C #   Jop       x            operating current density           A/m**2  
c #   TcsNb3Al    x          current sharing temperature           K
c #
c # Other functions called: 
c #
c # Author : Author at Cryosoft
c # Version: x.x   Date
c #
c ######################################################################
      implicit none
c *
      real     B,Epslon,Jop
c * fit variables      

c * local variables

c *      
      TcsNb3Al = 0.0

c *
      return
      end
